package member

import (
	"app-cloudep-portal-api-gateway/internal/domain"
	"app-cloudep-portal-api-gateway/internal/svc"
	"app-cloudep-portal-api-gateway/internal/types"
	"context"
	"fmt"

	ers "code.30cm.net/digimon/library-go/errors"
	accountRpc "code.30cm.net/digimon/proto-all/pkg/member"

	"github.com/zeromicro/go-zero/core/logx"
)

type CheckVerifyCodeLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCheckVerifyCodeLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CheckVerifyCodeLogic {
	return &CheckVerifyCodeLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *CheckVerifyCodeLogic) CheckVerifyCode(req *types.CheckoutVerifyReq) (resp *types.BaseResponse, err error) {
	// 驗證碼
	_, err = l.svcCtx.AccountRpc.CheckRefreshCode(l.ctx, &accountRpc.VerifyRefreshCodeReq{
		Account:    req.Account,
		CodeType:   domain.SendVerifyCodeTypeForgetPassword,
		VerifyCode: req.VerifyCode,
	})
	if err != nil {
		fmt.Println(err)
		// 表使沒有這驗證碼
		return nil, ers.Forbidden("failed to get verify code")
	}

	// 返回成功響應
	return &types.BaseResponse{
		Status: types.Status{
			Code:    domain.SuccessCode,
			Message: domain.SuccessMsg,
		},
	}, nil
}
